@@ -17,8 +17,8 @@
 //! If you are supporting Windows in any capacity, the [`is_windows_10()`] documentation is
 //! **required reading**.
 
-#![doc(html_favicon_url = "https://raw.githubusercontent.com/watchexec/clearscreen/main/logo.svg")]
-#![doc(html_logo_url = "https://raw.githubusercontent.com/watchexec/clearscreen/main/logo.svg")]
+#![doc(html_favicon_url = "https://watchexec.github.io/logo:clearscreen.svg")]
+#![doc(html_logo_url = "https://watchexec.github.io/logo:clearscreen.svg")]
 #![warn(missing_docs)]
 
 use std::{
@@ -342,14 +342,13 @@ impl Default for ClearScreen {
 
 		let term = var("TERM").ok();
 		let term = term.as_ref();
-		let terminfo = varfull("TERMINFO");
 
 		if cfg!(windows) {
 			return if is_microsoft_terminal() {
 				Self::XtermClear
 			} else if is_windows_10() {
 				Self::WindowsVtClear
-			} else if term.is_some() && terminfo {
+			} else if term.is_some() && varfull("TERMINFO") {
 				Self::Terminfo
 			} else if term.is_some() && which("tput").is_ok() {
 				Self::TputClear
@@ -442,6 +441,7 @@ impl ClearScreen {
 
 				if let Some(seq) = info.get::<capability::ClearScreen>() {
 					seq.expand().with(&mut ctx).to(&mut w)?;
+					w.flush()?;
 				} else {
 					return Err(Error::TerminfoCap("clear"));
 				}
@@ -453,7 +453,8 @@ impl ClearScreen {
 			Self::TerminfoScreen => {
 				let info = Database::from_env()?;
 				if let Some(seq) = info.get::<capability::ClearScreen>() {
-					seq.expand().to(w)?;
+					seq.expand().to(&mut w)?;
+					w.flush()?;
 				} else {
 					return Err(Error::TerminfoCap("clear"));
 				}
@@ -461,7 +462,8 @@ impl ClearScreen {
 			Self::TerminfoScrollback => {
 				let info = Database::from_env()?;
 				if let Some(seq) = info.get::<ResetScrollback>() {
-					seq.expand().to(w)?;
+					seq.expand().to(&mut w)?;
+					w.flush()?;
 				} else {
 					return Err(Error::TerminfoCap("E3"));
 				}
@@ -488,6 +490,8 @@ impl ClearScreen {
 					seq.expand().with(&mut ctx).to(&mut w)?;
 				}
 
+				w.flush()?;
+
 				if reset {
 					return Ok(());
 				}
@@ -509,6 +513,8 @@ impl ClearScreen {
 					seq.expand().with(&mut ctx).to(&mut w)?;
 				}
 
+				w.flush()?;
+
 				if !reset {
 					return Err(Error::TerminfoCap("reset"));
 				}
@@ -526,6 +532,8 @@ impl ClearScreen {
 
 				w.write_all(CSI)?;
 				w.write_all(ERASE_SCROLLBACK)?;
+
+				w.flush()?;
 			}
 			Self::XtermReset => {
 				const STR: &[u8] = b"!p";
@@ -551,6 +559,8 @@ impl ClearScreen {
 
 				w.write_all(CSI)?;
 				w.write_all(RESET_MARGINS)?;
+
+				w.flush()?;
 			}
 			Self::TputClear => {
 				let status = Command::new("tput").arg("clear").status()?;
@@ -584,11 +594,13 @@ impl ClearScreen {
 			Self::VtRis => {
 				w.write_all(ESC)?;
 				w.write_all(RIS)?;
+				w.flush()?;
 			}
 			Self::VtLeaveAlt => {
 				const LEAVE_ALT: &[u8] = b"?1049l";
 				w.write_all(CSI)?;
 				w.write_all(LEAVE_ALT)?;
+				w.flush()?;
 			}
 			Self::VtCooked => unix::vt_cooked()?,
 			Self::VtWellDone => unix::vt_well_done()?,
